Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(387)

Unified Diff: remoting/host/win/entry_point.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/win/elevated_controller.cc ('k') | remoting/host/win/host_service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/win/entry_point.cc
diff --git a/remoting/host/win/entry_point.cc b/remoting/host/win/entry_point.cc
index 3b54069dc2cb0c3b5e1a062ba0c862656ef46891..0d711f27807d54efeece6c29533675cf75759202 100644
--- a/remoting/host/win/entry_point.cc
+++ b/remoting/host/win/entry_point.cc
@@ -10,7 +10,7 @@
// order to be really small the app doesn't link against the CRT.
void HostEntryPoint() {
// CommandLine::Init() ignores the passed parameters on Windows, so it is safe
- // to pass NULL here.
- int exit_code = remoting::HostMain(0, NULL);
+ // to pass nullptr here.
+ int exit_code = remoting::HostMain(0, nullptr);
ExitProcess(exit_code);
}
« no previous file with comments | « remoting/host/win/elevated_controller.cc ('k') | remoting/host/win/host_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698